OC.L10N.register(
    "groupfolders",
    {
    "Group" : "Gruppe",
    "Create" : "Lag",
    "Delete" : "Ta bort",
    "Share" : "Del",
    "Add group" : "Legg til gruppe",
    "Unlimited" : "Ubegrensa",
    "Delete \"{folderName}\"?" : "Slett \"{folderName}\"?",
    "Folder name" : "Katalognavn",
    "Quota" : "Kvote",
    "Previous" : "Førre",
    "User" : "Bruker",
    "Unknown" : "Ukjend",
    "None" : "Ingen"
},
"nplurals=2; plural=(n != 1);");
